@@ -18,7 +18,11 @@
 # OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 # SOFTWARE.
 
-from simple_learn.classifiers import SimpleClassifier, SimpleClassifierList
+from simple_learn.classifiers.simple_classifier import SimpleClassifier
+from simple_learn.classifiers.simple_classifier_list import (
+    SimpleClassifierList,
+    SimpleClassifierListObject,
+)
 from simple_learn.version import version as current_version
 
 __name__ = "simple_learn"
